###############################
peltak - Improve your workflow
###############################

**peltak** is a command line utility to improve your daily workflow. The main
focus so far was making managing a gitlab merge request easier.

Installation
=============

::

    $ pip install peltak

Basic usage
============

Managing merge request
=======================

